# Hugin

[![Build Status](https://travis-ci.com/sage-group/hugin.svg?branch=master)](https://travis-ci.com/sage-group/hugin)

Hugin helps scientists run Machine Learning experiments on geospatial raster data.

Overall Hugin aims to facilitate experimentation with multiple machine learning problems, like:

 - Classification
 - Segmentation
 - Super-Resolution

Currently Hugin builds on top of the Keras machine learning library but it also aims to support, in the future, additional backends like scikit-learn.

Documentation for Hugin is available at https://hugin-eo.readthedocs.io/

## Acknowledgments

This project is supported by the European Space Agency through the ML4EO project.
